==> alfred-ui-native-components-0.0.133.tgz: package/ui/widgets/details/shutter/components/shutterQuickActions/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { LabelRegularText, ShadesOneHundredIcon, ShadesZeroIcon } from '../../../../../atoms';
import { useShutter } from '../../hooks/useShutter';
import { ShutterQuickActionsModel, ShutterQuickActionsValue } from '../shutterModels';
import { ShutterButton } from '../shutterButton';
import { styles } from '../styles';

const shutterQuickActionsValues: { [key: string]: ShutterQuickActionsValue} = {
  OPEN: 'OPEN',
  CLOSE: 'CLOSE',
};

export const ShutterQuickActions: FC<ShutterQuickActionsModel> = ({ 
  value,
  title,
  buttonOneText,
  buttonTwoText, 
  loading, 
  onClick, 
}) => {
  const { shutterAbsoluteAperture } = useShutter(value);

  return (
    <View>
      <View style={styles.shutterQuickActionsTitle}>
        <LabelRegularText numberOfLines={1} color={styles.shutterQuickActionsTitle.color}>{title}</LabelRegularText>
      </View>
      <View style={styles.shutterQuickActionsControls}>
        <View style={styles.shutterQuickActionsLeftButton}>
          <ShutterButton
            Icon={ShadesOneHundredIcon}
            text={buttonOneText}
            onClick={() => onClick?.(shutterQuickActionsValues.OPEN)}
            loading={loading}
            disabled={shutterAbsoluteAperture.FULLY_OPENED}
          />
        </View>
        <View style={styles.shutterQuickActionsRightButton}>
          <ShutterButton
            Icon={ShadesZeroIcon}
            text={buttonTwoText}
            onClick={() => onClick?.(shutterQuickActionsValues.CLOSE)}
            loading={loading}
            disabled={shutterAbsoluteAperture.FULLY_CLOSED}
          />
        </View>
      </View>
    </View>
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/widgets/details/shutter/components/shutterQuickActions/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { LabelRegularText, ShadesOneHundredIcon, ShadesZeroIcon } from '../../../../../atoms';
import { useShutter } from '../../hooks/useShutter';
import { ShutterQuickActionsModel, ShutterQuickActionsValue } from '../shutterModels';
import { ShutterButton } from '../shutterButton';
import { styles } from '../styles';

const shutterQuickActionsValues: { [key: string]: ShutterQuickActionsValue} = {
  OPEN: 'OPEN',
  CLOSE: 'CLOSE',
};

export const ShutterQuickActions: FC<ShutterQuickActionsModel> = ({
  value,
  title,
  buttonOneText,
  buttonTwoText,
  loading,
  onClick,
}) => {
  const { shutterAbsoluteAperture } = useShutter(value);

  return (
    <View>
      <View style={styles().shutterQuickActionsTitle}>
        <LabelRegularText numberOfLines={1} color={styles().shutterQuickActionsTitle.color}>{title}</LabelRegularText>
      </View>
      <View style={styles().shutterQuickActionsControls}>
        <View style={styles().shutterQuickActionsLeftButton}>
          <ShutterButton
            Icon={ShadesOneHundredIcon}
            text={buttonOneText}
            onClick={() => onClick?.(shutterQuickActionsValues.OPEN)}
            loading={loading}
            disabled={shutterAbsoluteAperture.FULLY_OPENED}
          />
        </View>
        <View style={styles().shutterQuickActionsRightButton}>
          <ShutterButton
            Icon={ShadesZeroIcon}
            text={buttonTwoText}
            onClick={() => onClick?.(shutterQuickActionsValues.CLOSE)}
            loading={loading}
            disabled={shutterAbsoluteAperture.FULLY_CLOSED}
          />
        </View>
      </View>
    </View>
  );
};
